@@ -6,7 +6,7 @@
  * pgpool: a language independent connection pool server for PostgreSQL 
  * written by Tatsuo Ishii
  *
- * Copyright (c) 2003-2015	PgPool Global Development Group
+ * Copyright (c) 2003-2016	PgPool Global Development Group
  *
  * Permission to use, copy, modify, and distribute this software and
  * its documentation for any purpose and without fee is hereby
@@ -293,7 +293,23 @@ int pool_virtual_master_db_node_id(void)
 
 	if (sc->query_context)
 	{
-		return sc->query_context->virtual_master_node_id;
+		int node_id = sc->query_context->virtual_master_node_id;
+
+		if (STREAM)
+		{
+			 /*
+			  * Make sure that virtual_master_node_id is either primary node
+			  * id or load balance node id.  If not, it is likely that
+			  * virtual_master_node_id is not set up yet. Let's use the
+			  * primary node id.
+			  */
+			if (node_id != sc->load_balance_node_id && node_id != PRIMARY_NODE_ID)
+			{
+				node_id = PRIMARY_NODE_ID;
+			}
+		}
+
+		return node_id;
 	}
 
 	/*
@@ -1329,7 +1345,8 @@ bool is_set_transaction_serializable(Node *node)
 		return false;
 
 	if (((VariableSetStmt *)node)->kind == VAR_SET_VALUE &&
-		!strcmp(((VariableSetStmt *)node)->name, "transaction_isolation"))
+		(!strcmp(((VariableSetStmt *)node)->name, "transaction_isolation") ||
+                 !strcmp(((VariableSetStmt *)node)->name, "default_transaction_isolation")))
 	{
 		List *options = ((VariableSetStmt *)node)->args;
 		foreach(list_item, options)
